@@ -6,8 +6,10 @@
 package org.jboss.as.clustering.infinispan.subsystem;
 
 import org.infinispan.Cache;
+import org.infinispan.factories.ComponentRegistry;
 import org.infinispan.interceptors.AsyncInterceptor;
-import org.jboss.as.clustering.controller.FunctionExecutorRegistry;
+import org.infinispan.interceptors.AsyncInterceptorChain;
+import org.wildfly.subsystem.service.capture.FunctionExecutorRegistry;
 
 /**
  * Executor for metrics based on a cache interceptor.
@@ -22,9 +24,8 @@ public class CacheInterceptorOperationExecutor<I extends AsyncInterceptor> exten
         this.interceptorClass = interceptorClass;
     }
 
-    @SuppressWarnings("deprecation")
     @Override
     public I apply(Cache<?, ?> cache) {
-        return cache.getAdvancedCache().getAsyncInterceptorChain().findInterceptorExtending(this.interceptorClass);
+        return ComponentRegistry.componentOf(cache.getAdvancedCache(), AsyncInterceptorChain.class).findInterceptorExtending(this.interceptorClass);
     }
 }
