@@ -6,8 +6,8 @@ package org.wildfly.clustering.web.undertow.session;
 
 import java.util.Map;
 
-import org.wildfly.clustering.ee.Batch;
-import org.wildfly.clustering.web.session.SessionManager;
+import org.wildfly.clustering.server.service.Service;
+import org.wildfly.clustering.session.SessionManager;
 
 import io.undertow.server.session.SessionListeners;
 
@@ -15,7 +15,7 @@ import io.undertow.server.session.SessionListeners;
  * Exposes additional session manager aspects to a session.
  * @author Paul Ferraro
  */
-public interface UndertowSessionManager extends io.undertow.server.session.SessionManager {
+public interface UndertowSessionManager extends io.undertow.server.session.SessionManager, Service {
     /**
      * Returns the configured session listeners for this web application
      * @return the session listeners
@@ -26,5 +26,20 @@ public interface UndertowSessionManager extends io.undertow.server.session.Sessi
      * Returns underlying distributable session manager implementation.
      * @return a session manager
      */
-    SessionManager<Map<String, Object>, Batch> getSessionManager();
+    SessionManager<Map<String, Object>> getSessionManager();
+
+    @Override
+    default boolean isStarted() {
+        return this.getSessionManager().isStarted();
+    }
+
+    @Override
+    default void start() {
+        this.getSessionManager().start();
+    }
+
+    @Override
+    default void stop() {
+        this.getSessionManager().stop();
+    }
 }
