@@ -7,6 +7,7 @@ package org.jboss.as.ejb3.deployment.processors.annotation;
 import org.jboss.as.ee.metadata.ClassAnnotationInformationFactory;
 import org.jboss.ejb3.annotation.DeliveryActive;
 import org.jboss.jandex.AnnotationInstance;
+import org.jboss.jandex.AnnotationValue;
 import org.jboss.metadata.property.PropertyReplacer;
 
 /**
@@ -22,6 +23,10 @@ public class DeliveryActiveAnnotationInformationFactory extends ClassAnnotationI
 
     @Override
     protected Boolean fromAnnotation(final AnnotationInstance annotationInstance, final PropertyReplacer propertyReplacer) {
-        return annotationInstance.value().asBoolean();
+        final AnnotationValue value = annotationInstance.value();
+        if (value == null) {
+            return Boolean.TRUE;
+        }
+        return value.asBoolean();
     }
 }
