@@ -757,4 +757,17 @@ public interface JpaLogger extends BasicLogger {
     @Message(id = 75, value="Illegal to call this method from injected, managed EntityManager")
     IllegalStateException illegalCallOnCloseMethod();
 
+    @LogMessage(level = INFO)
+    @Message(id = 76, value = "persistence.xml in application client %s deployment will not be deployed in server mode")
+    void ignoreAppclientPersistenceUnitsInServer(String deploymentName);
+
+    @Message(id = 77, value = "Jakarta Persistence/CDI Integration cannot be setup for bean type %s, persistence unit %s (%s)")
+    RuntimeException classNotFound(@Cause ClassNotFoundException cause, String beanType, String persistenceUnitName, String scopedPersistenceUnitName);
+
+    @Message(id = 78, value = "IntegratePersistenceAfterBeanDiscovery cannot register persistence unit %s as jakarta.enterprise.inject.spi.AfterBeanDiscovery event already ran for %s.")
+    IllegalStateException afterBeanDiscoveryEventRanAlready(String persistenceUnitName, String scopedPersistenceUnitName);
+
+    @LogMessage(level = INFO)
+    @Message(id = 79, value = "EntityManagerFactory CDI bean (for %s) will not have persistence unit name.  In order for the EntityManagerFactory CDI bean to be named remove duplicate copies of persistence unit %s.")
+    void willNotNameEntityManagerFactoryBean(String scopedPersistenceUnitName, String persistenceUnitName);
 }
