@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2012, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.jboss.as.jpa.processor;
@@ -26,11 +9,9 @@ import static org.jboss.as.jpa.messages.JpaLogger.ROOT_LOGGER;
 import static org.jboss.as.server.Services.addServerExecutorDependency;
 import static org.jboss.as.weld.Capabilities.WELD_CAPABILITY_NAME;
 
-import java.net.MalformedURLException;
-import java.net.URL;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -56,6 +37,8 @@ import org.jboss.as.ee.component.EEModuleDescription;
 import org.jboss.as.ee.structure.DeploymentType;
 import org.jboss.as.ee.structure.DeploymentTypeMarker;
 import org.jboss.as.jpa.beanmanager.BeanManagerAfterDeploymentValidation;
+import org.jboss.as.jpa.beanmanager.IntegrationWithCDIBagImpl;
+import org.jboss.as.jpa.beanmanager.PersistenceCdiExtension;
 import org.jboss.as.jpa.beanmanager.ProxyBeanManager;
 import org.jboss.as.jpa.config.Configuration;
 import org.jboss.as.jpa.config.PersistenceProviderDeploymentHolder;
@@ -94,7 +77,6 @@ import org.jboss.as.server.deployment.module.ResourceRoot;
 import org.jboss.as.weld.WeldCapability;
 import org.jboss.dmr.ModelNode;
 import org.jboss.dmr.ModelType;
-import org.jboss.jandex.Index;
 import org.jboss.modules.Module;
 import org.jboss.modules.ModuleClassLoader;
 import org.jboss.modules.ModuleLoadException;
@@ -137,6 +119,33 @@ public class PersistenceUnitServiceHandler {
 
         if( startEarly) {
             nextPhaseDependsOnPersistenceUnit(phaseContext, platform);
+            checkForDuplicates(phaseContext);
+        }
+    }
+
+    // mark all duplicate persistence unit definitions
+    private static void checkForDuplicates(DeploymentPhaseContext phaseContext) {
+        final DeploymentUnit topDeploymentUnit = DeploymentUtils.getTopDeploymentUnit(phaseContext.getDeploymentUnit());
+        final PersistenceUnitsInApplication persistenceUnitsInApplication = topDeploymentUnit.getAttachment(PersistenceUnitsInApplication.PERSISTENCE_UNITS_IN_APPLICATION);
+        ArrayList<String> duplicateList = new ArrayList<>();
+        HashSet<String> uniqueList = new HashSet<>(persistenceUnitsInApplication.getCount());
+        for(final PersistenceUnitMetadataHolder holder: persistenceUnitsInApplication.getPersistenceUnitHolders()) {
+            for (final PersistenceUnitMetadata pu : holder.getPersistenceUnits()) {
+                if (uniqueList.contains(pu.getPersistenceUnitName())) {
+                    duplicateList.add(pu.getPersistenceUnitName());
+                } else {
+                    uniqueList.add(pu.getPersistenceUnitName());
+                }
+            }
+        }
+        if (duplicateList.size() > 0) {
+            for(final PersistenceUnitMetadataHolder holder: persistenceUnitsInApplication.getPersistenceUnitHolders()) {
+                for (final PersistenceUnitMetadata pu : holder.getPersistenceUnits()) {
+                    if (duplicateList.contains(pu.getPersistenceUnitName())) {
+                        pu.setDuplicate(true);
+                    }
+                }
+            }
         }
     }
 
@@ -254,7 +263,6 @@ public class PersistenceUnitServiceHandler {
             final ModuleClassLoader classLoader = module.getClassLoader();
 
             for (PersistenceUnitMetadataHolder holder : puList) {
-                setAnnotationIndexes(holder, deploymentUnit);
                 for (PersistenceUnitMetadata pu : holder.getPersistenceUnits()) {
 
                     // only start the persistence unit if JPA_CONTAINER_MANAGED is true
@@ -364,13 +372,16 @@ public class PersistenceUnitServiceHandler {
             deploymentUnit.addToAttachmentList(Attachments.DEPLOYMENT_COMPLETE_SERVICES, puServiceName);
 
             deploymentUnit.addToAttachmentList(Attachments.WEB_DEPENDENCIES, puServiceName);
-
+            IntegrationWithCDIBagImpl integrationWithCDIBag = registerPersistenceAfterBeanDiscovery(deploymentUnit, capabilitySupport, pu, transactionManager, transactionSynchronizationRegistry);
             final PersistenceUnitServiceImpl service =
                     new PersistenceUnitServiceImpl(properties, classLoader, pu, adaptor, integratorAdaptors, provider,
                             PersistenceUnitRegistryImpl.INSTANCE,
                             deploymentUnit.getServiceName(), validatorFactory,
                             deploymentUnit.getAttachment(org.jboss.as.ee.naming.Attachments.JAVA_NAMESPACE_SETUP_ACTION),
-                            beanManagerAfterDeploymentValidation );
+                            beanManagerAfterDeploymentValidation,
+                            deploymentUnit.getAttachment(JpaAttachments.TRANSACTION_SYNCHRONIZATION_REGISTRY),
+                            ContextTransactionManager.getInstance(),
+                            integrationWithCDIBag);
 
             ServiceBuilder<PersistenceUnitService> builder = serviceTarget.addService(puServiceName, service);
             boolean useDefaultDataSource = Configuration.allowDefaultDataSourceUse(pu);
@@ -441,7 +452,6 @@ public class PersistenceUnitServiceHandler {
             addServerExecutorDependency(builder, service.getExecutorInjector());
 
             builder.install();
-
             ROOT_LOGGER.tracef("added PersistenceUnitService for '%s'.  PU is ready for injector action.", puServiceName);
             addManagementConsole(deploymentUnit, pu, adaptor, persistenceAdaptorRemoval);
 
@@ -508,8 +518,8 @@ public class PersistenceUnitServiceHandler {
             deploymentUnit.addToAttachmentList(Attachments.DEPLOYMENT_COMPLETE_SERVICES, puServiceName);
 
             deploymentUnit.addToAttachmentList(Attachments.WEB_DEPENDENCIES, puServiceName);
-
-            final PhaseOnePersistenceUnitServiceImpl service = new PhaseOnePersistenceUnitServiceImpl(classLoader, pu, adaptor, deploymentUnit.getServiceName(), proxyBeanManager);
+            IntegrationWithCDIBagImpl integrationWithCDIBag = registerPersistenceAfterBeanDiscovery(deploymentUnit, capabilitySupport, pu, null, null);
+            final PhaseOnePersistenceUnitServiceImpl service = new PhaseOnePersistenceUnitServiceImpl(classLoader, pu, adaptor, deploymentUnit.getServiceName(), proxyBeanManager, integrationWithCDIBag);
             service.getPropertiesInjector().inject(properties);
             ServiceBuilder<PhaseOnePersistenceUnitServiceImpl> builder = serviceTarget.addService(puServiceName, service);
 
@@ -627,7 +637,11 @@ public class PersistenceUnitServiceHandler {
                     adaptor, integratorAdaptors, provider, PersistenceUnitRegistryImpl.INSTANCE,
                     deploymentUnit.getServiceName(), validatorFactory,
                     deploymentUnit.getAttachment(org.jboss.as.ee.naming.Attachments.JAVA_NAMESPACE_SETUP_ACTION),
-                    beanManagerAfterDeploymentValidation);
+                    beanManagerAfterDeploymentValidation,
+                    transactionSynchronizationRegistry,
+                    ContextTransactionManager.getInstance(),
+                    null
+                    );
             ServiceBuilder<PersistenceUnitService> builder = serviceTarget.addService(puServiceName, service);
             // the PU service has to depend on the JPAService which is responsible for setting up the necessary JPA infrastructure (like registering the cache EventListener(s))
             // @see https://issues.jboss.org/browse/WFLY-1531 for details
@@ -678,6 +692,7 @@ public class PersistenceUnitServiceHandler {
             final CapabilityServiceSupport support = deploymentUnit.getAttachment(Attachments.CAPABILITY_SERVICE_SUPPORT);
             if (support.hasCapability(WELD_CAPABILITY_NAME)) {
                 support.getOptionalCapabilityRuntimeAPI(WELD_CAPABILITY_NAME, WeldCapability.class).get()
+
                         .addBeanManagerService(deploymentUnit, builder, service.getBeanManagerInjector());
             }
 
@@ -706,6 +721,7 @@ public class PersistenceUnitServiceHandler {
 
             builder.install();
 
+            // skip registerPersistenceAfterBeanDiscovery call as was done in phase 1 of 2
             ROOT_LOGGER.tracef("added PersistenceUnitService (phase 2 of 2) for '%s'.  PU is ready for injector action.", puServiceName);
             addManagementConsole(deploymentUnit, pu, adaptor, persistenceAdaptorRemoval);
 
@@ -715,6 +731,7 @@ public class PersistenceUnitServiceHandler {
     }
 
     private static void entityManagerBind(EEModuleDescription eeModuleDescription, ServiceTarget serviceTarget, final PersistenceUnitMetadata pu, ServiceName puServiceName, TransactionManager transactionManager, TransactionSynchronizationRegistry transactionSynchronizationRegistry) {
+
         if (pu.getProperties().containsKey(ENTITYMANAGER_JNDI_PROPERTY)) {
             String jndiName = pu.getProperties().get(ENTITYMANAGER_JNDI_PROPERTY).toString();
             final ContextNames.BindInfo bindingInfo;
@@ -735,7 +752,7 @@ public class PersistenceUnitServiceHandler {
                         binderService.getManagedObjectInjector().inject(new ValueManagedReferenceFactory(
                                         new TransactionScopedEntityManager(
                                                 pu.getScopedPersistenceUnitName(),
-                                                Collections.emptyMap(),
+                                                new HashMap(),      // WFLY-19973: pass empty HashMap that can be modified by application code.
                                                 value.getEntityManagerFactory(),
                                                 SynchronizationType.SYNCHRONIZED, transactionSynchronizationRegistry, transactionManager)));
                     }
@@ -777,39 +794,6 @@ public class PersistenceUnitServiceHandler {
         }
     }
 
-    /**
-     * Setup the annotation index map
-     *
-     * @param puHolder
-     * @param deploymentUnit
-     */
-    private static void setAnnotationIndexes(
-            final PersistenceUnitMetadataHolder puHolder,
-            DeploymentUnit deploymentUnit ) {
-
-        final Map<URL, Index> annotationIndexes = new HashMap<>();
-
-        do {
-            for (ResourceRoot root : DeploymentUtils.allResourceRoots(deploymentUnit)) {
-                final Index index = root.getAttachment(Attachments.ANNOTATION_INDEX);
-                if (index != null) {
-                    try {
-                        ROOT_LOGGER.tracef("adding '%s' to annotation index map", root.getRoot().toURL());
-                        annotationIndexes.put(root.getRoot().toURL(), index);
-                    } catch (MalformedURLException e) {
-                        throw new RuntimeException(e);
-                    }
-                }
-            }
-            deploymentUnit = deploymentUnit.getParent(); // get annotation indexes for top level also
-        }
-        while (deploymentUnit != null);
-
-        for (PersistenceUnitMetadata pu : puHolder.getPersistenceUnits()) {
-            pu.setAnnotationIndex(annotationIndexes);   // hold onto the annotation index for Persistence Provider use during deployment
-        }
-    }
-
     private static String adjustJndi(String dataSourceName) {
         if (dataSourceName != null && dataSourceName.length() > 0 && !dataSourceName.startsWith("java:")) {
             if (dataSourceName.startsWith("jboss/")) {
@@ -1196,6 +1180,42 @@ public class PersistenceUnitServiceHandler {
         return deploymentUnit.getAttachment(JpaAttachments.DEPLOYED_PERSISTENCE_PROVIDER);
     }
 
+    private static IntegrationWithCDIBagImpl registerPersistenceAfterBeanDiscovery(DeploymentUnit deploymentUnit, CapabilityServiceSupport support, PersistenceUnitMetadata pu, TransactionManager transactionManager, TransactionSynchronizationRegistry transactionSynchronizationRegistry) {
+        deploymentUnit = DeploymentUtils.getTopDeploymentUnit(deploymentUnit);
+        IntegrationWithCDIBagImpl result = null;
+        if (support.hasCapability(WELD_CAPABILITY_NAME)) {
+            Optional<WeldCapability> weldCapability = support.getOptionalCapabilityRuntimeAPI(WELD_CAPABILITY_NAME, WeldCapability.class);
+
+            if (weldCapability.get().isPartOfWeldDeployment(deploymentUnit)) {
+                final Module module = deploymentUnit.getAttachment(Attachments.MODULE);
+
+                PersistenceCdiExtension persistenceCdiExtension = deploymentUnit.getAttachment(JpaAttachments.AFTER_BEAN_DISCOVERY_ATTACHMENT_KEY);
+                if (null == persistenceCdiExtension) {
+                    // ensure that only one of multiple per deployment threads register the persistenceCdiExtension and the other per app deployment threads block
+                    // For an EAR deployment `deploymentUnit` will always be set to the ear.
+                    // For a standalone war/jar deployment `deploymentUnit` will always be set to the war/jar deployment.
+                    synchronized (deploymentUnit) {
+                        persistenceCdiExtension = deploymentUnit.getAttachment(JpaAttachments.AFTER_BEAN_DISCOVERY_ATTACHMENT_KEY);
+                        if (null == persistenceCdiExtension) {
+                            persistenceCdiExtension = module.loadService(PersistenceCdiExtension.class).findFirst().orElse(null);
+                            if (persistenceCdiExtension != null) {
+                                deploymentUnit.putAttachment(JpaAttachments.AFTER_BEAN_DISCOVERY_ATTACHMENT_KEY, persistenceCdiExtension);
+                                weldCapability.get().registerExtensionInstance(persistenceCdiExtension, deploymentUnit);
+                            }
+                        }
+                    }
+                }
+                if ( persistenceCdiExtension != null) {
+                    // register the persistence unit with the CDI Persistence extension that we registered above
+                    result = persistenceCdiExtension.register(pu);
+                    result.setTransactionManager(transactionManager);
+                    result.setTransactionSynchronizationRegistry(transactionSynchronizationRegistry);
+                }
+            }
+        }
+        return result;
+    }
+
     private static BeanManagerAfterDeploymentValidation registerJPAEntityListenerRegister(DeploymentUnit deploymentUnit, CapabilityServiceSupport support) {
         deploymentUnit = DeploymentUtils.getTopDeploymentUnit(deploymentUnit);
         if (support.hasCapability(WELD_CAPABILITY_NAME)) {
