@@ -1,26 +1,10 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2014, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 package org.jboss.as.test.integration.ws.wsse.trust;
 
+import java.util.PropertyPermission;
 import org.apache.commons.io.IOUtils;
 import org.apache.cxf.Bus;
 import org.apache.cxf.BusFactory;
@@ -42,6 +26,7 @@ import org.jboss.as.test.integration.ws.wsse.trust.service.ServiceIface;
 import org.jboss.as.test.shared.TestSuiteEnvironment;
 import org.jboss.dmr.ModelNode;
 import org.jboss.shrinkwrap.api.ShrinkWrap;
+import org.jboss.shrinkwrap.api.asset.Asset;
 import org.jboss.shrinkwrap.api.asset.StringAsset;
 import org.jboss.shrinkwrap.api.exporter.ZipExporter;
 import org.jboss.shrinkwrap.api.spec.JavaArchive;
@@ -56,8 +41,8 @@ import org.junit.runner.Description;
 import org.junit.runner.RunWith;
 
 import javax.xml.namespace.QName;
-import javax.xml.ws.BindingProvider;
-import javax.xml.ws.Service;
+import jakarta.xml.ws.BindingProvider;
+import jakarta.xml.ws.Service;
 import java.io.File;
 import java.io.IOException;
 import java.net.URL;
@@ -65,6 +50,7 @@ import java.net.URLClassLoader;
 import java.nio.charset.StandardCharsets;
 import java.util.StringTokenizer;
 
+import static org.jboss.as.test.shared.PermissionUtils.createPermissionsXmlAsset;
 import static org.junit.Assert.assertEquals;
 
 /**
@@ -86,7 +72,6 @@ public class WSTrustTestCase {
     private static final String ON_BEHALF_OF_SERVER_DEP = "jaxws-samples-wsse-policy-trust-onbehalfof";
     private static final String HOLDER_OF_KEY_STS_DEP = "jaxws-samples-wsse-policy-trust-sts-holderofkey";
     private static final String HOLDER_OF_KEY_SERVER_DEP = "jaxws-samples-wsse-policy-trust-holderofkey";
-    private static final String PL_STS_DEP = "jaxws-samples-wsse-policy-trustPicketLink-sts";
     private static final String BEARER_STS_DEP = "jaxws-samples-wsse-policy-trust-sts-bearer";
     private static final String BEARER_SERVER_DEP = "jaxws-samples-wsse-policy-trust-bearer";
     @Rule
@@ -94,12 +79,27 @@ public class WSTrustTestCase {
     @ArquillianResource
     private URL serviceURL;
 
+    public static Asset PERMISSIONS = createPermissionsXmlAsset(
+            new PropertyPermission("node0", "read"),
+            new PropertyPermission("java.net.preferIPv4Stack", "read"),
+            new PropertyPermission("java.net.preferIPv6Addresses", "read"));
+
+    public static Asset EXTRA_PERMISSIONS = createPermissionsXmlAsset(
+            new PropertyPermission("node0", "read"),
+            new PropertyPermission("java.net.preferIPv4Stack", "read"),
+            new PropertyPermission("java.net.preferIPv6Addresses", "read"),
+            new RuntimePermission("accessDeclaredMembers"),
+            new RuntimePermission("getClassLoader"),
+            new PropertyPermission("user.dir", "read"),
+            new RuntimePermission("createClassLoader"));
+
     @Deployment(name = STS_DEP, testable = false)
     public static WebArchive createSTSDeployment() {
+
         WebArchive archive = ShrinkWrap.create(WebArchive.class, STS_DEP + ".war");
         archive
                 .setManifest(new StringAsset("Manifest-Version: 1.0\n"
-                        + "Dependencies: org.jboss.ws.cxf.jbossws-cxf-client,org.jboss.ws.cxf.sts annotations\n"))
+                        + "Dependencies: org.jboss.ws.cxf.jbossws-cxf-client,org.jboss.ws.cxf.sts export services\n"))
                 .addClass(org.jboss.as.test.integration.ws.wsse.trust.sts.STSCallbackHandler.class)
                 .addClass(org.jboss.as.test.integration.ws.wsse.trust.sts.SampleSTS.class)
                 .addClass(org.jboss.as.test.integration.ws.wsse.trust.shared.WSTrustAppUtils.class)
@@ -108,7 +108,7 @@ public class WSTrustTestCase {
 
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsstore.jks", "classes/stsstore.jks")
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsKeystore.properties", "classes/stsKeystore.properties")
-                .addAsManifestResource(WSTrustTestCase.class.getPackage(), "WEB-INF/permissions.xml", "permissions.xml")
+                .addAsManifestResource(PERMISSIONS, "permissions.xml")
                 .setWebXML(WSTrustTestCase.class.getPackage(), "WEB-INF/web.xml");
         return archive;
     }
@@ -128,24 +128,7 @@ public class WSTrustTestCase {
                 .addAsWebInfResource(createFilteredAsset("WEB-INF/wsdl/SecurityService_schema1.xsd"), "wsdl/SecurityService_schema1.xsd")
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/servicestore.jks", "classes/servicestore.jks")
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/serviceKeystore.properties", "classes/serviceKeystore.properties")
-                .addAsManifestResource(WSTrustTestCase.class.getPackage(), "WEB-INF/permissions.xml", "permissions.xml");
-        return archive;
-    }
-
-    @Deployment(name = PL_STS_DEP, testable = false)
-    public static WebArchive createPicketLinkSTSDeployment() {
-        WebArchive archive = ShrinkWrap.create(WebArchive.class, PL_STS_DEP + ".war");
-        archive
-                .setManifest(new StringAsset("Manifest-Version: 1.0\n"
-                        + "Dependencies: org.jboss.ws.cxf.jbossws-cxf-client,org.picketlink\n"))
-                .addClass(org.jboss.as.test.integration.ws.wsse.trust.picketlink.PicketLinkSTService.class)
-                .addClass(org.jboss.as.test.integration.ws.wsse.trust.sts.STSCallbackHandler.class)
-                .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/jboss-web.xml", "jboss-web.xml")
-                .addAsWebInfResource(createFilteredAsset("WEB-INF/wsdl/PicketLinkSTS.wsdl"), "wsdl/PicketLinkSTS.wsdl")
-                .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsstore.jks", "classes/stsstore.jks")
-                .addAsWebInfResource(createFilteredAsset("WEB-INF/picketlink-sts.xml"), "classes/picketlink-sts.xml")
-                .
-                        addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsKeystore.properties", "classes/stsKeystore.properties");
+                .addAsManifestResource(PERMISSIONS, "permissions.xml");
         return archive;
     }
 
@@ -167,7 +150,7 @@ public class WSTrustTestCase {
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/actasKeystore.properties", "classes/actasKeystore.properties")
                 .addAsManifestResource(WSTrustTestCase.class.getPackage(), "META-INF/clientstore.jks", "clientstore.jks")
                 .addAsManifestResource(WSTrustTestCase.class.getPackage(), "META-INF/clientKeystore.properties", "clientKeystore.properties")
-                .addAsManifestResource(WSTrustTestCase.class.getPackage(), "META-INF/permissions.xml", "permissions.xml");
+                .addAsManifestResource(EXTRA_PERMISSIONS, "permissions.xml");
         return archive;
     }
 
@@ -189,7 +172,7 @@ public class WSTrustTestCase {
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/actasKeystore.properties", "classes/actasKeystore.properties")
                 .addAsManifestResource(WSTrustTestCase.class.getPackage(), "META-INF/clientstore.jks", "clientstore.jks")
                 .addAsManifestResource(WSTrustTestCase.class.getPackage(), "META-INF/clientKeystore.properties", "clientKeystore.properties")
-                .addAsManifestResource(WSTrustTestCase.class.getPackage(), "META-INF/permissions.xml", "permissions.xml");
+                .addAsManifestResource(EXTRA_PERMISSIONS, "permissions.xml");
         return archive;
     }
 
@@ -206,7 +189,7 @@ public class WSTrustTestCase {
                 .addAsWebInfResource(createFilteredAsset("WEB-INF/wsdl/holderofkey-ws-trust-1.4-service.wsdl"), "wsdl/holderofkey-ws-trust-1.4-service.wsdl")
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsstore.jks", "classes/stsstore.jks")
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsKeystore.properties", "classes/stsKeystore.properties")
-                .addAsManifestResource(WSTrustTestCase.class.getPackage(), "WEB-INF/permissions.xml", "permissions.xml")
+                .addAsManifestResource(PERMISSIONS, "permissions.xml")
                 .setWebXML(WSTrustTestCase.class.getPackage(), "WEB-INF/holderofkey/web.xml");
         return archive;
     }
@@ -242,7 +225,7 @@ public class WSTrustTestCase {
                 .addAsWebInfResource(createFilteredAsset("WEB-INF/wsdl/bearer-ws-trust-1.4-service.wsdl"), "wsdl/bearer-ws-trust-1.4-service.wsdl")
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsstore.jks", "classes/stsstore.jks")
                 .addAsWebInfResource(WSTrustTestCase.class.getPackage(), "WEB-INF/stsKeystore.properties", "classes/stsKeystore.properties")
-                .addAsManifestResource(WSTrustTestCase.class.getPackage(), "META-INF/permissions.xml", "permissions.xml")
+                .addAsManifestResource(EXTRA_PERMISSIONS, "permissions.xml")
                 .setWebXML(WSTrustTestCase.class.getPackage(), "WEB-INF/bearer/web.xml");
         return archive;
     }
@@ -498,35 +481,6 @@ public class WSTrustTestCase {
         }
     }
 
-    @Test
-    @RunAsClient
-    @OperateOnDeployment(SERVER_DEP)
-    @WrapThreadContextClassLoader
-    public void testPicketLink() throws Exception {
-        Bus bus = BusFactory.newInstance().createBus();
-        try {
-            BusFactory.setThreadDefaultBus(bus);
-
-            final QName serviceName = new QName("http://www.jboss.org/jbossws/ws-extensions/wssecuritypolicy", "SecurityService");
-            final URL wsdlURL = new URL(serviceURL + "SecurityService?wsdl");
-            Service service = Service.create(wsdlURL, serviceName);
-            ServiceIface proxy = (ServiceIface) service.getPort(ServiceIface.class);
-
-            final QName stsServiceName = new QName("urn:picketlink:identity-federation:sts", "PicketLinkSTS");
-            final QName stsPortName = new QName("urn:picketlink:identity-federation:sts", "PicketLinkSTSPort");
-            final URL stsURL = new URL(serviceURL.getProtocol(), serviceURL.getHost(), serviceURL.getPort(), "/jaxws-samples-wsse-policy-trustPicketLink-sts/PicketLinkSTS?wsdl");
-            WSTrustTestUtils.setupWsseAndSTSClient(proxy, bus, stsURL.toString(), stsServiceName, stsPortName);
-
-            try {
-                assertEquals("WS-Trust Hello World!", proxy.sayHello());
-            } catch (Exception e) {
-                throw e;
-            }
-        } finally {
-            bus.shutdown(true);
-        }
-    }
-
     @Test
     @RunAsClient
     @OperateOnDeployment(BEARER_SERVER_DEP)
