@@ -52,8 +52,6 @@ public abstract class LayersTestBase {
             "org.hornetq.client",
             // TODO we need to add an xts layer
             "org.jboss.as.xts",
-            // TODO should an undertow layer specify this?
-            "org.wildfly.event.logger",
     };
 
     /**
@@ -63,7 +61,9 @@ public abstract class LayersTestBase {
     public static final String[] NO_LAYER_WILDFLY_EE = {
             // In 'wildfly-ee' this is only a dep of org.apache.activemq.artemis.protocol.amqp,
             // which is not part of test-all-layers. It is used in a layer in 'wildfly' and 'wildfly-preview'
-            "org.apache.qpid.proton"
+            "org.apache.qpid.proton",
+            // 'preview' stability module so not yet included in "all-layers" installation
+            "jakarta.data.api"
     };
 
     /**
@@ -88,7 +88,11 @@ public abstract class LayersTestBase {
             "org.wildfly.extension.mvc-krazo",
             "jakarta.mvc.api",
             "org.eclipse.krazo.core",
-            "org.eclipse.krazo.resteasy"
+            "org.eclipse.krazo.resteasy",
+            // 'preview' stability extension so not yet included in
+            // the "all-layers" installation
+            "org.wildfly.extension.jakarta.data",
+            "jakarta.data.api",
     };
 
     /**
@@ -98,6 +102,7 @@ public abstract class LayersTestBase {
     public static final String[] NO_LAYER_WILDFLY_PREVIEW = {
             // WFP standard config uses Micrometer instead of WF Metrics
             "org.wildfly.extension.metrics",
+            "org.wildfly.extension.security.manager",
     };
 
     /**
@@ -133,8 +138,6 @@ public abstract class LayersTestBase {
             "org.wildfly.security.elytron-tool",
             // bootable jar runtime
             "org.wildfly.bootable-jar",
-            // Extension not included in the default config
-            "org.wildfly.extension.clustering.singleton",
             // Dynamically added by ee-security and mp-jwt-smallrye DUPs but not referenced by subsystems.
             "org.wildfly.security.jakarta.security",
             // injected by sar
@@ -147,8 +150,6 @@ public abstract class LayersTestBase {
             "org.infinispan.cdi.common",
             "org.infinispan.cdi.embedded",
             "org.infinispan.cdi.remote",
-            "org.infinispan.counter",
-            "org.infinispan.lock",
             "org.infinispan.query",
             "org.infinispan.query.core",
             // WFLY-8770 jgroups-aws layer modules needed to configure the aws.S3_PING protocol are not referenced
@@ -162,7 +163,7 @@ public abstract class LayersTestBase {
             "org.wildfly.extension.mod_cluster",
             "org.wildfly.mod_cluster.undertow",
             // Brought by galleon ServerRootResourceDefinition
-            "wildflyee.api"
+            "wildflyee.api",
     };
 
 
@@ -172,8 +173,6 @@ public abstract class LayersTestBase {
      */
     public static final String[] NOT_REFERENCED_WILDFLY_EE = {
             // Only injected by logging in 'wildfly-ee', but referenced in 'wildfly' and 'wildfly-preview'
-            "org.apache.logging.log4j.api",
-            "org.jboss.logmanager.log4j2",
     };
 
 
@@ -195,10 +194,11 @@ public abstract class LayersTestBase {
             // Extension not included in the default config
             "org.wildfly.extension.microprofile.lra-coordinator",
             "org.wildfly.extension.microprofile.lra-participant",
-            "org.jboss.narayana.rts.lra-service-base",
-            "org.jboss.narayana.rts.lra-coordinator",
-            "org.jboss.narayana.rts.lra-participant",
+            "org.jboss.narayana.lra.lra-service-base",
+            "org.jboss.narayana.lra.lra-coordinator",
+            "org.jboss.narayana.lra.lra-participant",
             "org.eclipse.microprofile.lra.api",
+            "io.smallrye.stork",
             // Extension not included in the default config
             "org.wildfly.extension.microprofile.openapi-smallrye",
             "org.eclipse.microprofile.openapi.api",
@@ -235,13 +235,15 @@ public abstract class LayersTestBase {
             "org.wildfly.extension.micrometer",
             "org.wildfly.micrometer.deployment",
             "io.micrometer",
-            "com.google.protobuf",
+            "io.prometheus",
             "io.opentelemetry.proto",
             // Extension not included in the default config
             "org.wildfly.extension.mvc-krazo",
             "jakarta.mvc.api",
             "org.eclipse.krazo.core",
             "org.eclipse.krazo.resteasy",
+            // 'preview' stability extension so not yet included in the standard configs
+            "org.wildfly.extension.jakarta.data",
     };
 
     /**
@@ -253,9 +255,13 @@ public abstract class LayersTestBase {
             "org.wildfly.extension.metrics",
             // Extension not included in the default config
             "org.wildfly.extension.mvc-krazo",
+            "org.wildfly.extension.security.manager",
             "jakarta.mvc.api",
             "org.eclipse.krazo.core",
-            "org.eclipse.krazo.resteasy"
+            "org.eclipse.krazo.resteasy",
+            // Not needed for WildFly as this module is effectively replaced by org.hibernate.models.hibernate-models
+            "org.hibernate.commons-annotations",
+            "org.wildfly.extension.vertx"
     };
 
     /**
@@ -319,7 +325,10 @@ public abstract class LayersTestBase {
             "io.reactivex.rxjava2.rxjava",
             // Downstream uses this in installations provisioned with wildfly-ee but upstream does not.
             // To make life easier downstream we include it in wildfly-ee.
-            "com.fasterxml.jackson.dataformat.jackson-dataformat-yaml"
+            "com.fasterxml.jackson.dataformat.jackson-dataformat-yaml",
+            // 'preview' stability extension so not yet included in
+            // the "all-layers" installation or the standard configs
+            "org.wildfly.extension.jakarta.data"
     };
 
     /**
